@@ -1,26 +1,10 @@
 /*
-  Copyright (c) 1998 Preston Brown <pbrown@kde.org>
-  Copyright (C) 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2008 Ron Goodheart <rong.dev@gmail.com>
-  Copyright (c) 2012-2013 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 1998 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2008 Ron Goodheart <rong.dev@gmail.com>
+  SPDX-FileCopyrightText: 2012-2013 Allen Winter <winter@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef CALENDARSUPPORT_CALPRINTDEFAULTPLUGINS_H
 #define CALENDARSUPPORT_CALPRINTDEFAULTPLUGINS_H
@@ -28,50 +12,51 @@
 #include "calendarsupport_export.h"
 #include "calprintpluginbase.h"
 
-#include "ui_calprintincidenceconfig_base.h"
 #include "ui_calprintdayconfig_base.h"
-#include "ui_calprintweekconfig_base.h"
+#include "ui_calprintincidenceconfig_base.h"
 #include "ui_calprintmonthconfig_base.h"
 #include "ui_calprinttodoconfig_base.h"
+#include "ui_calprintweekconfig_base.h"
 
 #include <KLocalizedString>
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 class CALENDARSUPPORT_EXPORT CalPrintIncidence : public CalPrintPluginBase
 {
 public:
     CalPrintIncidence();
     ~CalPrintIncidence() override;
-    QString groupName() const override
+    Q_REQUIRED_RESULT QString groupName() const override
     {
         return QStringLiteral("Print incidence");
     }
 
-    QString description() const override
+    Q_REQUIRED_RESULT QString description() const override
     {
         return i18n("Print &incidence");
     }
 
-    QString info() const override
+    Q_REQUIRED_RESULT QString info() const override
     {
         return i18n("Prints an incidence on one page");
     }
 
-    int sortID() const override
+    Q_REQUIRED_RESULT int sortID() const override
     {
         return CalPrinterBase::Incidence;
     }
 
     // Enable the Print Incidence option only if there are selected incidences.
-    bool enabled() const override
+    Q_REQUIRED_RESULT bool enabled() const override
     {
         return !mSelectedIncidences.isEmpty();
     }
 
     QWidget *createConfigWidget(QWidget *) override;
-    QPrinter::Orientation defaultOrientation() const override
+    Q_REQUIRED_RESULT QPageLayout::Orientation defaultOrientation() const override
     {
-        return QPrinter::Portrait;
+        return QPageLayout::Portrait;
     }
 
 public:
@@ -82,8 +67,7 @@ public:
     void saveConfig() override;
 
 protected:
-    int printCaptionAndText(QPainter &p, const QRect &box, const QString &caption,
-                            const QString &text, const QFont &captionFont, const QFont &textFont);
+    int printCaptionAndText(QPainter &p, const QRect &box, const QString &caption, const QString &text, const QFont &captionFont, const QFont &textFont);
 
     bool mShowOptions;
     bool mShowSubitemsNotes;
@@ -132,11 +116,7 @@ public:
     void setDateRange(const QDate &from, const QDate &to) override;
 
 protected:
-    enum eDayPrintType {
-        Filofax = 0,
-        Timetable,
-        SingleTimetable
-    } mDayPrintType;
+    enum eDayPrintType { Filofax = 0, Timetable, SingleTimetable } mDayPrintType;
     QTime mStartTime, mEndTime;
     bool mIncludeDescription;
     bool mSingleLineLimit;
@@ -183,7 +163,7 @@ public:
     /**
       Returns the default orientation for the eWeekPrintType.
     */
-    QPrinter::Orientation defaultOrientation() const override;
+    QPageLayout::Orientation defaultOrientation() const override;
 
 public:
     void print(QPainter &p, int width, int height) override;
@@ -194,11 +174,7 @@ public:
     void setDateRange(const QDate &from, const QDate &to) override;
 
 protected:
-    enum eWeekPrintType {
-        Filofax = 0,
-        Timetable,
-        SplitWeek
-    } mWeekPrintType;
+    enum eWeekPrintType { Filofax = 0, Timetable, SplitWeek } mWeekPrintType;
     QTime mStartTime, mEndTime;
     bool mSingleLineLimit;
     bool mIncludeTodos;
@@ -239,9 +215,9 @@ public:
     }
 
     QWidget *createConfigWidget(QWidget *) override;
-    QPrinter::Orientation defaultOrientation() const override
+    QPageLayout::Orientation defaultOrientation() const override
     {
-        return QPrinter::Landscape;
+        return QPageLayout::Landscape;
     }
 
 public:
@@ -306,11 +282,7 @@ public:
 protected:
     QString mPageTitle;
 
-    enum eTodoPrintType {
-        TodosAll = 0,
-        TodosUnfinished,
-        TodosDueRange
-    } mTodoPrintType;
+    enum eTodoPrintType { TodosAll = 0, TodosUnfinished, TodosDueRange } mTodoPrintType;
 
     enum eTodoSortField {
         TodoFieldSummary = 0,
@@ -321,11 +293,7 @@ protected:
         TodoFieldUnset
     } mTodoSortField;
 
-    enum eTodoSortDirection {
-        TodoDirectionAscending = 0,
-        TodoDirectionDescending,
-        TodoDirectionUnset
-    } mTodoSortDirection;
+    enum eTodoSortDirection { TodoDirectionAscending = 0, TodoDirectionDescending, TodoDirectionUnset } mTodoSortDirection;
 
     bool mIncludeDescription;
     bool mIncludePriority;
@@ -343,7 +311,8 @@ class CalPrintIncidenceConfig : public QWidget, public Ui::CalPrintIncidenceConf
 {
     Q_OBJECT
 public:
-    explicit CalPrintIncidenceConfig(QWidget *parent) : QWidget(parent)
+    explicit CalPrintIncidenceConfig(QWidget *parent)
+        : QWidget(parent)
     {
         setupUi(this);
     }
@@ -353,7 +322,8 @@ class CalPrintDayConfig : public QWidget, public Ui::CalPrintDayConfig_Base
 {
     Q_OBJECT
 public:
-    explicit CalPrintDayConfig(QWidget *parent) : QWidget(parent)
+    explicit CalPrintDayConfig(QWidget *parent)
+        : QWidget(parent)
     {
         setupUi(this);
     }
@@ -363,7 +333,8 @@ class CalPrintWeekConfig : public QWidget, public Ui::CalPrintWeekConfig_Base
 {
     Q_OBJECT
 public:
-    explicit CalPrintWeekConfig(QWidget *parent) : QWidget(parent)
+    explicit CalPrintWeekConfig(QWidget *parent)
+        : QWidget(parent)
     {
         setupUi(this);
     }
@@ -373,7 +344,8 @@ class CalPrintMonthConfig : public QWidget, public Ui::CalPrintMonthConfig_Base
 {
     Q_OBJECT
 public:
-    explicit CalPrintMonthConfig(QWidget *parent) : QWidget(parent)
+    explicit CalPrintMonthConfig(QWidget *parent)
+        : QWidget(parent)
     {
         setupUi(this);
     }
@@ -383,7 +355,8 @@ class CalPrintTodoConfig : public QWidget, public Ui::CalPrintTodoConfig_Base
 {
     Q_OBJECT
 public:
-    explicit CalPrintTodoConfig(QWidget *parent) : QWidget(parent)
+    explicit CalPrintTodoConfig(QWidget *parent)
+        : QWidget(parent)
     {
         setupUi(this);
     }
